==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/global_resources/translations/agendaplugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>Agenda</name>
    <message>
        <location filename="../../plugins/agendaplugin/constants.h" line="190"/>
        <source>Print current selection</source>
        <translation>Auswahl drucken</translation>
    </message>
</context>
<context>
    <name>Agenda::AgendaPlugin</name>
    <message>
        <location filename="../../plugins/agendaplugin/agendaplugin.cpp" line="115"/>
        <source>Initializing agenda plugin...</source>
        <translation>Agenda-Plugin wird initialisiert...</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/agendaplugin.cpp" line="122"/>
        <source>Creating agenda base...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/agendaplugin.cpp" line="122"/>
        <source>Please wait</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Agenda::AvailabilityCreatorDialog</name>
    <message>
        <location filename="../../plugins/agendaplugin/availabilitycreatordialog.ui" line="14"/>
        <source>Dialog</source>
        <translatorcomment>??? this should not be a translatable string!&quot;</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/availabilitycreatordialog.ui" line="32"/>
        <source>Day availability creator</source>
        <translatorcomment>skipped &quot;creator&quot;, translated only &quot;Day availability&quot;</translatorcomment>
        <translation>Tagesverfügbarkeit</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/availabilitycreatordialog.ui" line="49"/>
        <source>Day of week</source>
        <translation>Wochentag</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/availabilitycreatordialog.ui" line="59"/>
        <source>Start time</source>
        <translation>Startzeit</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/availabilitycreatordialog.ui" line="69"/>
        <source>End time</source>
        <translation>Endzeit</translation>
    </message>
</context>
<context>
    <name>Agenda::CalendarItemModel</name>
    <message>
        <location filename="../../plugins/agendaplugin/calendaritemmodel.cpp" line="321"/>
        <source>Empty</source>
        <translation>Leer</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::AgendaMode</name>
    <message>
        <location filename="../../plugins/agendaplugin/agendamode.cpp" line="61"/>
        <location filename="../../plugins/agendaplugin/agendamode.cpp" line="79"/>
        <source>Agenda</source>
        <translation>Agenda</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::AgendaPreferencesPage</name>
    <message>
        <location filename="../../plugins/agendaplugin/agendapreferencespage.cpp" line="75"/>
        <source>Agenda preferences</source>
        <translation>Agenda-Einstellungen</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::AgendaPreferencesWidget</name>
    <message>
        <location filename="../../plugins/agendaplugin/agendapreferencespage.ui" line="14"/>
        <source>Form</source>
        <translatorcomment>??? this should not be translatable</translatorcomment>
        <translation></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::CalendarItemEditorPatientMapper</name>
    <message>
        <location filename="../../plugins/agendaplugin/calendaritemeditorpatientmapper.ui" line="14"/>
        <source>Form</source>
        <translatorcomment>??? this should not be translatable???</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/calendaritemeditorpatientmapper.ui" line="26"/>
        <source>Patients</source>
        <translation>Patienten</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/calendaritemeditorpatientmapper.ui" line="46"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::CalendarItemEditorPatientMapperWidget</name>
    <message>
        <location filename="../../plugins/agendaplugin/calendaritemeditorpatientmapper.cpp" line="157"/>
        <location filename="../../plugins/agendaplugin/calendaritemeditorpatientmapper.cpp" line="158"/>
        <location filename="../../plugins/agendaplugin/calendaritemeditorpatientmapper.cpp" line="288"/>
        <location filename="../../plugins/agendaplugin/calendaritemeditorpatientmapper.cpp" line="289"/>
        <source>Add current patient</source>
        <translation>Aktuellen Patienten hinzufügen</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::NextAvailabiliyStepViewer</name>
    <message>
        <location filename="../../plugins/agendaplugin/nextavailabiliystepviewer.ui" line="14"/>
        <source>Form</source>
        <translatorcomment>??? this should not be translatable</translatorcomment>
        <translation></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarDelegatesMapperWidget</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendardelegatesmapper.ui" line="14"/>
        <source>Form</source>
        <translatorcomment>??? this should not be translatable???</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendardelegatesmapper.ui" line="23"/>
        <source>Delegates</source>
        <translatorcomment>maybe better translation needed</translatorcomment>
        <translation>Delegierte</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendardelegatesmapper.ui" line="43"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarPageForUserViewer</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarpageforuserviewer.cpp" line="139"/>
        <source>User agendas</source>
        <translation>Benutzer-Agendas</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarViewer</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.ui" line="14"/>
        <source>Form</source>
        <translatorcomment>??? this should not be translatable</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.ui" line="27"/>
        <source>You are</source>
        <translation>Sie sind</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.ui" line="52"/>
        <source>Your agendas</source>
        <translation>Ihre Agendas</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.ui" line="68"/>
        <source>Availabilities</source>
        <translation>Verfügbarkeiten</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.ui" line="97"/>
        <source>Search parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.ui" line="172"/>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.ui" line="214"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.cpp" line="366"/>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.cpp" line="432"/>
        <source>Set back to default: </source>
        <extracomment>default agenda duration time (in minutes)
----------
default agenda duration time (in minutes)</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarWizardCreatorPage</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="62"/>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="67"/>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="72"/>
        <source>User&apos;s agendas</source>
        <translation>Benutzer-Agendas</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarWizardCreatorWidget</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="14"/>
        <source>Form</source>
        <translatorcomment>??? why is this a translatable string?</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="20"/>
        <source>Quick params</source>
        <translatorcomment>maybe bad translation</translatorcomment>
        <translation>Schnelle Einstellungen</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="32"/>
        <source>Label</source>
        <translation>Bezeichnung</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="61"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="84"/>
        <source>Default appointement duration</source>
        <translation>Standard-Terminlänge</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="104"/>
        <source>minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="111"/>
        <source>Default location</source>
        <translation>Standard-Ort</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="137"/>
        <source>Do you want to create an agenda for this user ?</source>
        <translation>Möchten Sie eine Agenda für diesen Benutzer erstellen?</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="143"/>
        <source>Create an agenda</source>
        <translation>Agenda erstellen</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarWizardPage</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="124"/>
        <source>Please specify a label for this agenda.</source>
        <translation>Bitte geben Sie eine Bezeichnung für diese Agenda an.</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="127"/>
        <source>The default duration can not be null.</source>
        <translatorcomment>???&quot;null&quot; maybe should be in &lt;i&gt; or &quot;</translatorcomment>
        <translation>Die Standarddauer kann nicht &lt;i&gt;Null&lt;/i&gt; sein.</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="130"/>
        <source>Error detected</source>
        <translation>Fehler gefunden</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="140"/>
        <source>Manage an agenda.</source>
        <translatorcomment>??? why a &quot;.&quot; at the end? Maybe without &quot;an&quot;</translatorcomment>
        <translation>Eine Agenda verwalten.</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="141"/>
        <source>You can quickly define an agenda for this user. This agenda will be the default one.</source>
        <translation>Sie können schnell eine Agenda für diesen Benutzer definieren. Diese Agenda wird dann die Standard-Agenda.</translation>
    </message>
</context>
<context>
    <name>Agenda::UserCalendarEditorWidget</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="14"/>
        <source>Form</source>
        <translatorcomment>??? this should not be translated!!!</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="20"/>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="67"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="103"/>
        <source>Label</source>
        <translation>Bezeichnung</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="48"/>
        <source>Icon</source>
        <translation>Symbol</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="90"/>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="134"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="149"/>
        <source>Default event duration</source>
        <translation>Standard-Ereignisdauer</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="172"/>
        <source>Default location</source>
        <translatorcomment>&quot;Ort&quot; is maybe a bit bad translated. check needed.</translatorcomment>
        <translation>Standard-Ort</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="156"/>
        <source> minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="182"/>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="195"/>
        <source>Agenda is the default agenda</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="202"/>
        <source>Agenda is private</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="210"/>
        <source>Shared</source>
        <translation>Gemeiname Benutzung</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="236"/>
        <source>Availabilities</source>
        <translation>Verfügbarkeiten</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="261"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="271"/>
        <source>Clear</source>
        <translation>Leeren</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="278"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.cpp" line="150"/>
        <location filename="../../plugins/agendaplugin/usercalendareditor.cpp" line="162"/>
        <source>Can not delete all availabilities</source>
        <translation>Alle Verfügbarkeiten können nicht gelöscht werden</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.cpp" line="151"/>
        <location filename="../../plugins/agendaplugin/usercalendareditor.cpp" line="163"/>
        <source>Agenda must have at least one availability. You can not delete all its availabilities.</source>
        <translation>Es muss mindestens eine Verfügbarkeit in der Agenda vorhanden sein. Sie können nicht alle Verfügbarkeiten löschen.</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.cpp" line="155"/>
        <source>Delete full day.</source>
        <translation>Ganzen Tag löschen</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.cpp" line="156"/>
        <source>You are about to delete all recorded time range for one specific day of the week (%1). Do you really want to delete all time range?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Agenda::UserCalendarModelFullEditorWidget</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarmodelfulleditorwidget.ui" line="14"/>
        <source>Form</source>
        <translatorcomment>??? this should not be translatable</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarmodelfulleditorwidget.cpp" line="72"/>
        <location filename="../../plugins/agendaplugin/usercalendarmodelfulleditorwidget.cpp" line="127"/>
        <source>Create a new calendar</source>
        <translation>Neuen Kalender erstellen</translation>
    </message>
</context>
<context>
    <name>AgendaBase</name>
    <message>
        <location filename="../../plugins/agendaplugin/agendabase.cpp" line="410"/>
        <source>Trying to create empty database.
       Location: %1
       FileName: %2
       Driver: %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freemedforms-project_0.8.0.orig.tar.gz: freemedforms-0.8.0/global_resources/translations/agendaplugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>Agenda</name>
    <message>
        <source>Print current selection</source>
        <translation>Auswahl drucken</translation>
    </message>
</context>
<context>
    <name>Agenda::AgendaPlugin</name>
    <message>
        <source>Initializing agenda plugin...</source>
        <translation>Agenda-Plugin wird initialisiert...</translation>
    </message>
    <message>
        <source>Creating agenda base...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Agenda::AvailabilityCreatorDialog</name>
    <message>
        <source>Day availability creator</source>
        <translatorcomment>skipped &quot;creator&quot;, translated only &quot;Day availability&quot;</translatorcomment>
        <translation>Tagesverfügbarkeit</translation>
    </message>
    <message>
        <source>Day of week</source>
        <translation>Wochentag</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Startzeit</translation>
    </message>
    <message>
        <source>End time</source>
        <translation>Endzeit</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Agenda::CalendarItemModel</name>
    <message>
        <source>Empty</source>
        <translation>Leer</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::AgendaMode</name>
    <message>
        <source>Agenda</source>
        <translation>Agenda</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::AgendaPreferencesPage</name>
    <message>
        <source>Agenda preferences</source>
        <translation>Agenda-Einstellungen</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::AgendaPreferencesWidget</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::CalendarItemEditorPatientMapper</name>
    <message>
        <source>Patients</source>
        <translation>Patienten</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::CalendarItemEditorPatientMapperWidget</name>
    <message>
        <source>Add current patient</source>
        <translation>Aktuellen Patienten hinzufügen</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::NextAvailabiliyStepViewer</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarDelegatesMapperWidget</name>
    <message>
        <source>Delegates</source>
        <translatorcomment>maybe better translation needed</translatorcomment>
        <translation>Delegierte</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarPageForUserViewer</name>
    <message>
        <source>User agendas</source>
        <translation>Benutzer-Agendas</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarViewer</name>
    <message>
        <source>Availabilities</source>
        <translation>Verfügbarkeiten</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available appointments:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refresh Availabilities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set back to default: %1 %2</source>
        <extracomment>default agenda duration time, %1 = time, %2 = minutes (fixed)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Agendas of %1</source>
        <extracomment>e.g. Agendas of John Doe</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set back to default: </source>
        <extracomment>default agenda duration time (in minutes)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Beginning of next week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Beginning of next month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to patient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit appointment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print appointment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete appointment</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarWizardCreatorPage</name>
    <message>
        <source>User&apos;s agendas</source>
        <translation>Benutzer-Agendas</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarWizardCreatorWidget</name>
    <message>
        <source>Quick params</source>
        <translatorcomment>maybe bad translation</translatorcomment>
        <translation>Schnelle Einstellungen</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Bezeichnung</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <source>Default location</source>
        <translation>Standard-Ort</translation>
    </message>
    <message>
        <source>Do you want to create an agenda for this user ?</source>
        <translation>Möchten Sie eine Agenda für diesen Benutzer erstellen?</translation>
    </message>
    <message>
        <source>Create an agenda</source>
        <translation>Agenda erstellen</translation>
    </message>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default appointment duration</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarWizardPage</name>
    <message>
        <source>Please specify a label for this agenda.</source>
        <translation>Bitte geben Sie eine Bezeichnung für diese Agenda an.</translation>
    </message>
    <message>
        <source>The default duration can not be null.</source>
        <translatorcomment>???&quot;null&quot; maybe should be in &lt;i&gt; or &quot;</translatorcomment>
        <translation>Die Standarddauer kann nicht &lt;i&gt;Null&lt;/i&gt; sein.</translation>
    </message>
    <message>
        <source>Error detected</source>
        <translation>Fehler gefunden</translation>
    </message>
    <message>
        <source>Manage an agenda.</source>
        <translatorcomment>??? why a &quot;.&quot; at the end? Maybe without &quot;an&quot;</translatorcomment>
        <translation>Eine Agenda verwalten.</translation>
    </message>
    <message>
        <source>You can quickly define an agenda for this user. This agenda will be the default one.</source>
        <translation>Sie können schnell eine Agenda für diesen Benutzer definieren. Diese Agenda wird dann die Standard-Agenda.</translation>
    </message>
</context>
<context>
    <name>Agenda::UserCalendarEditorWidget</name>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Bezeichnung</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Symbol</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Default event duration</source>
        <translation>Standard-Ereignisdauer</translation>
    </message>
    <message>
        <source>Default location</source>
        <translatorcomment>&quot;Ort&quot; is maybe a bit bad translated. check needed.</translatorcomment>
        <translation>Standard-Ort</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Gemeiname Benutzung</translation>
    </message>
    <message>
        <source>Availabilities</source>
        <translation>Verfügbarkeiten</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Leeren</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Can not delete all availabilities</source>
        <translation>Alle Verfügbarkeiten können nicht gelöscht werden</translation>
    </message>
    <message>
        <source>Agenda must have at least one availability. You can not delete all its availabilities.</source>
        <translation>Es muss mindestens eine Verfügbarkeit in der Agenda vorhanden sein. Sie können nicht alle Verfügbarkeiten löschen.</translation>
    </message>
    <message>
        <source>Delete full day.</source>
        <translation>Ganzen Tag löschen</translation>
    </message>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Agenda is the default agenda</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Agenda is private</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You are about to delete all recorded time range for one specific day of the week (%1). Do you really want to delete all time range?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Agenda::UserCalendarModelFullEditorWidget</name>
    <message>
        <source>Create a new calendar</source>
        <translation>Neuen Kalender erstellen</translation>
    </message>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AgendaBase</name>
    <message>
        <source>Trying to create empty database.
       Location: %1
       FileName: %2
       Driver: %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
